py7zr documentation contents
============================

.. toctree::
   :maxdepth: 2

   py7zr
   design_and_classes
   7zFormat
   AUTHORS
   glossary

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

